Eyes Selenium Python SDK
========================

Applitools Eyes SDK For Selenium Python WebDriver

Installation
------------

Install the eyes-selenium SDK.

::

    pip install eyes-selenium

Usage
-----

Please check the applitools website for usage instructions:

-  Selenium Python example:
   https://applitools.com/resources/tutorial/selenium/python#step-2

-  Python Appium native example:
   https://applitools.com/resources/tutorial/appium/native\_python#step-2

-  Python Appium web example:
   https://applitools.com/resources/tutorial/appium/python#step-2
